#!/usr/bin/perl -w  # -*- cperl -*- #
#
#  uptime.pm - Handle the "ethernet" commands:
#
#   ip
#   mac
#   tx
#   rx
#
#  NOTE: The commands assume that each instance has only a single ethN
#        device.  This should be corrected.
#
#  Steve Kemp
#  ---
#  http://www.steve.org.uk/
#
#


#
#  The package this module is implementing.
#
package Xen::Monitor::Plugins::mac;


#
#  Register the plugin.
#
Xen::Monitor::Server::register_plugin("Xen::Monitor::Plugins::mac");



#
#  Minimal constructor.
#
sub new { return bless {}; }



#
#  Return the author of this plugin.
#
sub getAuthor
{
    return( 'Steve Kemp <steve@steve.org.uk>' );
}


#
#  Does this plugin require authentication?
#
sub needsAuth
{
    return 1;
}

#
#  Return the commands we handle.
#
sub getCommand
{
    my %commands;
    $commands{"ip"}  = 1;
    $commands{"mac"} = 1;
    $commands{"tx"}  = 1;
    $commands{"rx"}  = 1;
    return( %commands );
}


#
# Run the command we're sent - this means one of:
#
#  tx  - Show transmitted data count.
#  rx  - Show received data count.
#  mac - Show MAC address.
#  ip  - Show IP address.
#
sub runCommand
{
    my ( $class, $server, $command, @args ) = ( @_ );

    my $host = shift( @args );

    if ( !defined( $host ) )
    {
	print "400 MISSING HOST\r\n";
	return;
    }

    if ( ! $server->canControl( $host ) )
    {
	print "400 NOT ALLOWED\r\n";
	return;
    }

    my $instance = Xen::Host->new( name => $host );

    if ( ( $instance->isRunning() ) ||
	 ( $instance->isPaused() ) )
    {
	if ( $command eq "mac" )
	{
	    print "200 OK\r\n";
	    print $instance->getMAC() . "\r\n";
	    print "300 DONE\r\n";
	}
	elsif ( $command eq "tx" )
	{
	    print "200 OK\r\n";
	    print $instance->getTX() . "\r\n";
	    print "300 DONE\r\n";
	}
	elsif ( $command eq "rx" )
	{
	    print "200 OK\r\n";
	    print $instance->getRX() . "\r\n";
	    print "300 DONE\r\n";
	}
	elsif ( $command eq "ip" )
	{
	    print "200 OK\r\n";
	    print $instance->getIPAddress() . "\r\n";
	    print "300 DONE\r\n";
	}
    }
    else
    {
	print "400 NOT RUNNING\r\n";
    }
}


1;
