#!/usr/bin/perl -w  # -*- cperl -*- #
#
#  info.pm - list information about a given host.
#
#  Steve Kemp
#  ---
#  http://www.steve.org.uk/
#
#


#
#  The package this module is implementing.
#
package Xen::Monitor::Plugins::info;


#
#  Register the plugin.
#
Xen::Monitor::Server::register_plugin("Xen::Monitor::Plugins::info");



#
#  Minimal constructor.
#
sub new { return bless {}; }



#
#  Return the author of this plugin.
#
sub getAuthor
{
    return( 'Steve Kemp <steve@steve.org.uk>' );
}


#
#  Does this plugin require authentication?
#
sub needsAuth
{
    return 1;
}
#
#  Return the commands we handle.
#
sub getCommand
{
    my %commands;
    $commands{"info"}	 = 1;
    return( %commands );
}


#
# Run the command we're sent.
#
sub runCommand
{
    my ( $class, $server, $command, @args ) = ( @_ );

    #
    #  Find the type of list the client wants.
    #
    my ( $host ) = ( @args );
    if ( !defined( $host ) )
    {
	print "400 MISSING HOST\r\n";
	return;
    }

    #
    #  Test to see if the user can execute the given command
    #
    if ( ! $server->canControl( $host ) )
    {
	print "400 NOT ALLOWED\r\n";
	return;
    }

    my $monitor = Xen::Host->new( name => $host);
    
    print "200 OK\r\n";

    print "Name: "   . $monitor->getName() . "\r\n";
    print "Memory: " . $monitor->getMemory() . "\r\n";
    print "IP: "     . $monitor->getIPAddress() . "\r\n";

    if ( $monitor->isPaused() )
    {
	print "eth0 MAC: " . $monitor->getMAC() . "\r\n";
	print "eth0 tx: "  . $monitor->getTX()  . "\r\n";
	print "eth0 rx: "  . $monitor->getRX()  . "\r\n";
	print "State: Paused\r\n";
	print "Uptime:   " . $monitor->getUptime() . "\r\n";
    }
    elsif ( $monitor->isRunning() )
    {
	print "eth0 MAC: " . $monitor->getMAC() . "\r\n";
	print "eth0 tx: "  . $monitor->getTX()  . "\r\n";
	print "eth0 rx: "  . $monitor->getRX()  . "\r\n";
	print "State: Running\r\n";
	print "Uptime: " . $monitor->getUptime() . "\r\n";
    }
    else
    {
	print "State: Off\r\n";
    }

    print "300 DONE\r\n";
}



1;
