#!/usr/bin/perl -w  # -*- cperl -*- #
#
#  list.pm - List available, or running Xen instances.
#
#  Steve Kemp
#  ---
#  http://www.steve.org.uk/
#
#


#
#  The package this module is implementing.
#
package Xen::Monitor::Plugins::list;


#
#  Register the plugin.
#
Xen::Monitor::Server::register_plugin("Xen::Monitor::Plugins::list");



#
#  Minimal constructor.
#
sub new { return bless {}; }



#
#  Return the author of this plugin.
#
sub getAuthor
{
    return( 'Steve Kemp <steve@steve.org.uk>' );
}


#
#  Does this plugin require authentication?
#
sub needsAuth
{
    return 1;
}
#
#  Return the commands we handle.
#
sub getCommand
{
    my %commands;
    $commands{"list"}	 = 1;
    return( %commands );
}


#
# Run the command we're sent - this means 'list available' or 'list running'.
#
sub runCommand
{
    my ( $class, $server, $command, @args ) = ( @_ );

    #
    #  Find the type of list the client wants.
    #
    my ( $type ) = ( @args );
    if ( !defined( $type ) )
    {
	print "400 MISSING TYPE\r\n";
	return;
    }

    my $monitor = Xen::Monitor->new();
    
    if ( $type eq "available" )
    {
	print "200 OK\r\n";
	foreach my $host ( $monitor->getAvailable() )
	{
	    if ( $server->canControl( $host->getName() ) )
	    {
		print $host->getName() . "\r\n";
	    }
	}
	print "300 DONE\r\n";
    }
    elsif( $type eq "running" )
    {
	print "200 OK\r\n";
	foreach my $host ( $monitor->getRunning() )
	{
	    if ( $server->canControl( $host->getName() ) )
	    {
		print $host->getName() . "\r\n";
	    }
	}
	print "300 DONE\r\n";

    }
    else
    {
	print "400 UNKNOWN TYPE\r\n";
    }
}



1;
